@@ -1,4 +1,4 @@
-
+_PY = _PY or {}
 local mobdebug = require("mobdebug")
 _PY.mobdebug.on()
 local class = require("class")
@@ -40,6 +40,7 @@ function Emulator:__init()
   end
   self.config.hc3_user = os.getenv("HC3_USER")
   self.config.hc3_password = os.getenv("HC3_PASSWORD")
+  self.config.hc3_pin = os.getenv("HC3_PIN")
   if self.config.hc3_user and self.config.hc3_password then
     self.config.hc3_creds = _PY.base64_encode(self.config.hc3_user..":"..self.config.hc3_password)
   end
@@ -501,7 +502,7 @@ function Emulator:loadQA(info,envAdds)
   envAdds = envAdds or {}
   local env = { 
     fibaro = { plua = self }, net = net, json = json, api = self.api, 
-    os = { time = self.lib.userTime, date = self.lib.userDate, getenv = os.getenv, clock = os.clock, difftime = os.difftime },
+    os = { time = self.lib.userTime, date = self.lib.userDate, getenv = os.getenv, clock = os.clock, difftime = os.difftime, exit = os.exit },
     __fibaro_add_debug_message = self.lib.__fibaro_add_debug_message, _PY = _PY,
   }
   for _,name in ipairs(stdLua) do env[name] = _G[name] end
@@ -568,7 +569,7 @@ function Emulator:startQA(id)
   coroutine.wraptest = coroutine.wraptest
   if coroutine.wraptest then return coroutine.wraptest(func,info) end
   coroutine.wrapdebug(func, function(err,tb)
-    err = err:match(":(%d+: .*)")
+    err = tostring(err):match(":(%d+: .*)") or err
     print("Error in QA " .. id .. ": " .. tostring(err))
     print(tb)
   end)() 
@@ -633,6 +634,7 @@ function Emulator:HC3_CALL(method, path, data)
         ["User-Agent"] = "plua/0.1.0",
         ["Content-Type"] = "application/json",
         ["Authorization"] = "Basic " .. (self.config.hc3_creds or ""),
+        ['Fibaro-User-PIN'] = self.config.hc3_pin
       }
     })
   end
@@ -761,7 +763,7 @@ function headerKeys.file(str,info)
   assert(path,"Invalid file header: "..str)
   if path:sub(1,1) == '$' then
     local lpath = package.searchpath(path:sub(2),package.path)
-    if _PY.file_exists(lpath) then path = lpath
+    if _PY.file_exists(lpath or "x") then path = lpath
     else error(fmt("Library not found: '%s'",path)) end
   elseif path:sub(1,1) == '%' then
     path = info.path..path:sub(2) -- Relative to the QA path
