@@ -1,6 +1,7 @@
 fibaro = fibaro or {}
 local fmt = string.format
 __TAG = __TAG or "PLUA"
+--_PY = _PY or {}
 
 -- A simple ternary operator implementation.
 -- @param c - The condition.
@@ -204,7 +205,6 @@ function fibaro.call(deviceId, action, ...)
     __assert_type(deviceId, "number")
     local arg = {...}
     local arg2 = #arg>0 and arg or nil
-    print(json.encodeFast(arg2))
     return api.post("/devices/"..deviceId.."/action/"..action, { args = arg2 })
   end
 end
