@@ -283,6 +283,8 @@ def run_engine(
                                         ["netstat", "-ano", "-p", "TCP"], 
                                         capture_output=True, 
                                         text=True, 
+                                        encoding='utf-8',
+                                        errors='replace',
                                         check=False
                                     )
                                     
@@ -315,6 +317,8 @@ def run_engine(
                                                 ["netstat", "-ano", "-p", "TCP"], 
                                                 capture_output=True, 
                                                 text=True, 
+                                                encoding='utf-8',
+                                                errors='replace',
                                                 check=False
                                             )
                                             
@@ -346,6 +350,8 @@ def run_engine(
                                     ["lsof", "-ti", f":{port}"], 
                                     capture_output=True, 
                                     text=True, 
+                                    encoding='utf-8',
+                                    errors='replace',
                                     check=False
                                 )
                                 if result.stdout.strip():
@@ -376,7 +382,7 @@ def run_engine(
                         
                         # Start FastAPI in separate process
                         api_manager = start_fastapi_process(
-                            host=config.get("api_host", "localhost"),
+                            host=config.get("api_host", "0.0.0.0"),
                             port=api_port,
                             config=config
                         )
@@ -777,8 +783,8 @@ def main():
     )
     parser.add_argument(
         "--api-host",
-        default="localhost", 
-        help="Host for FastAPI server (default: localhost)",
+        default="0.0.0.0", 
+        help="Host for FastAPI server (default: 0.0.0.0 - all interfaces)",
     )
     parser.add_argument(
         "--telnet-port",
